@@ -6,7 +6,7 @@ test_that("inputs to GBIFtableCleanup from gbifRetriever as expected", {
   oldwd <- getwd()
   on.exit(setwd(oldwd))
 
-  setwd(dir = system.file('extdata/', package='occCite'))
+  setwd(dir = system.file("extdata/", package = "occCite"))
   taxon <- "Protea cynaroides"
   testResult <- occCite:::gbifRetriever(taxon)
 
@@ -17,23 +17,28 @@ test_that("inputs to GBIFtableCleanup from gbifRetriever as expected", {
 test_that("inputs to GBIFtableCleanup from getGBIFpoints as expected", {
   skip_on_cran()
 
-  test <- try(rgbif::occ_download(user=GBIFLogin@username,
-                            email = GBIFLogin@email,
-                            pwd = GBIFLogin@pwd,
-                            rgbif::pred("catalogNumber", 217880)),
-              silent = T)
-  skip_if(class(test) != 'occ_download', "GBIF login unsuccessful")
+  test <- try(rgbif::occ_download(
+    user = GBIFLogin@username,
+    email = GBIFLogin@email,
+    pwd = GBIFLogin@pwd,
+    rgbif::pred("catalogNumber", 217880)
+  ),
+  silent = T
+  )
+  skip_if(class(test) != "occ_download", "GBIF login unsuccessful")
 
   oldwd <- getwd()
   on.exit(setwd(oldwd))
 
-  setwd(dir = system.file('extdata/', package='occCite'))
+  setwd(dir = system.file("extdata/", package = "occCite"))
   taxon <- "Protea cynaroides"
-  if(!dir.exists("temp/")) dir.create("temp/")
-  testResult <- occCite:::getGBIFpoints(taxon = taxon,
-                        GBIFLogin = occCite:::GBIFLoginManager(),
-                        GBIFDownloadDirectory = "temp/",
-                        checkPreviousGBIFDownload = T)
+  if (!dir.exists("temp/")) dir.create("temp/")
+  testResult <- occCite:::getGBIFpoints(
+    taxon = taxon,
+    GBIFLogin = occCite:::GBIFLoginManager(),
+    GBIFDownloadDirectory = "temp/",
+    checkPreviousGBIFDownload = T
+  )
 
   expect_equal(class(testResult[[1]]), "data.frame")
   expect_equal(names(testResult)[[1]], "OccurrenceTable")
@@ -45,7 +50,7 @@ test_that("GBIFtableCleanup behaves as expected when given a stored GBIF table",
   oldwd <- getwd()
   on.exit(setwd(oldwd))
 
-  setwd(dir = system.file('extdata/', package='occCite'))
+  setwd(dir = system.file("extdata/", package = "occCite"))
   taxon <- "Protea cynaroides"
   testResult <- occCite:::gbifRetriever(taxon)[[1]]
 
@@ -64,26 +69,33 @@ test_that("GBIFtableCleanup behaves as expected when given a stored GBIF table",
 
 test_that("GBIFtableCleanup behaves as expected when given a downloaded GBIF table", {
   skip_on_cran()
-  skip_if(nchar(Sys.getenv("GBIF_EMAIL")) < 1,
-          "GBIF Login information not available")
+  skip_if(
+    nchar(Sys.getenv("GBIF_EMAIL")) < 1,
+    "GBIF Login information not available"
+  )
 
-  test <- try(rgbif::occ_download(user=GBIFLogin@username,
-                                  email = GBIFLogin@email,
-                                  pwd = GBIFLogin@pwd,
-                                  rgbif::pred("catalogNumber", 217880)),
-              silent = T)
-  skip_if(class(test) != 'occ_download', "GBIF login unsuccessful")
+  test <- try(rgbif::occ_download(
+    user = GBIFLogin@username,
+    email = GBIFLogin@email,
+    pwd = GBIFLogin@pwd,
+    rgbif::pred("catalogNumber", 217880)
+  ),
+  silent = T
+  )
+  skip_if(class(test) != "occ_download", "GBIF login unsuccessful")
 
   oldwd <- getwd()
   on.exit(setwd(oldwd))
 
-  setwd(dir = system.file('extdata/', package='occCite'))
+  setwd(dir = system.file("extdata/", package = "occCite"))
   taxon <- "Protea cynaroides"
-  if(!dir.exists("temp/")) dir.create("temp/")
-  testResult <- occCite:::getGBIFpoints(taxon = taxon,
-                                GBIFLogin = occCite:::GBIFLoginManager(),
-                                GBIFDownloadDirectory = "temp/",
-                                checkPreviousGBIFDownload = T)[[1]]
+  if (!dir.exists("temp/")) dir.create("temp/")
+  testResult <- occCite:::getGBIFpoints(
+    taxon = taxon,
+    GBIFLogin = occCite:::GBIFLoginManager(),
+    GBIFDownloadDirectory = "temp/",
+    checkPreviousGBIFDownload = T
+  )[[1]]
 
   expect_equal(class(testResult), "data.frame")
   expect_true("gbifID" %in% colnames(testResult))
